#!/bin/env python3

import yaml
from collections import OrderedDict
from unidecode import unidecode

contributions = OrderedDict( # sort contributions by starting page
  sorted(yaml.load(open('isipta15contrib.yaml')).items(),
         key=lambda x: x[1]['pages'][0]))

bibtex = ''

for key, entry in contributions.items():
  surnames = [unidecode(fullname.rsplit(maxsplit=1)[-1])
              for fullname in entry['authors']]
  id_stub = surnames.pop(0)
  if len(surnames) is 1:
    id_stub += '+' + surnames[0]
  if len(surnames) > 1:
    id_stub += '+' + ''.join(surname[0] for surname in surnames)
  bibtex += "@INPROCEEDINGS{{{}-ISIPTA15{},\n".format(id_stub, 'p' if entry['type'] == 'paper' else 'a')
  bibtex += "  AUTHOR = {{{}}},\n".format(' and '.join(entry['authors']))
  bibtex += "  TITLE = {{{}}},\n".format(entry['title'])
  bibtex += "  BOOKTITLE = {ISIPTA '15: Proceedings of the Ninth International Symposium on Imprecise Probability: Theories and Applications},\n"
  bibtex += "  EDITOR = {Thomas Augustin and Serena Doria and Enrique Miranda and Erik Quaeghebeur},\n"
  bibtex += "  PAGES = {{{0[0]}--{0[1]}}},\n".format(entry['pages'])
  bibtex += "  URL = {{http://www.sipta.org/isipta15/data/{}/{}.pdf}},\n".format('paper' if entry['type'] == 'paper' else 'abstract', key)
  if 'keywords' in entry:
    bibtex += "  KEYWORDS = {{{}}},\n".format(', '.join(entry['keywords']))
  if 'abstract' in entry:
    bibtex += "  ABSTRACT = {{{}}},\n".format(entry['abstract'])
  bibtex += "}\n\n"

# Ad hoc corrections
bibtex = bibtex.replace('Jasper De Bock', 'De Bock, Jasper')
bibtex = bibtex.replace('Arthur Van Camp', 'Van Camp, Arthur')
bibtex = bibtex.replace('Doria-ISIPTA15p,', 'Doria-ISIPTA15p_congl,', 1)
bibtex = bibtex.replace('Doria-ISIPTA15p,', 'Doria-ISIPTA15p_risk,', 1)

# Write to std-out
print(bibtex)
